'''
This is the main script of our python package
'''
# importing the requests library
import requests
 
# api-endpoint
URL = "http://maps.googleapis.com/maps/api/geocode/json"
 

# function to get formatted address of passed location
def get_address(location):
	# defining a params dict for the parameters to be sent to the API
	PARAMS = {'address':location}
	 
	# sending get request and saving the response as response object
	r = requests.get(url = URL, params = PARAMS)
	 
	# extracting data in json format
	data = r.json()
	 
	 
	# extracting formatted address 
	# of the first matching location
	formatted_address = data['results'][0]['formatted_address']
	 
	# returning the output
	return(formatted_address)

# function to get latitude-longitude of passed location
def get_coordinates(location):
	# defining a params dict for the parameters to be sent to the API
	PARAMS = {'address':location}
	 
	# sending get request and saving the response as response object
	r = requests.get(url = URL, params = PARAMS)
	 
	# extracting data in json format
	data = r.json()
	 
	 
	# extracting latitude, longitude
	# of the first matching location
	latitude = data['results'][0]['geometry']['location']['lat']
	longitude = data['results'][0]['geometry']['location']['lng']
	 
	# returning the output
	return(latitude, longitude)





from setuptools import setup

# reading long description from file
with open('README.md') as file:
    long_description = file.read()


# specify requirements of your package here
REQUIREMENTS = ['requests']

# some more details
CLASSIFIERS = [
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'Topic :: Internet',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.6',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    ]

# calling the setup function 
setup(name='arnger1',
      version='1.0.1',
      description='lawrence sample',
      long_description=long_description,
      url='https://github.com/arnger',
      author='Lawrence.Net',
      author_email='arnger@gmail.com',
      license='MIT',
      packages=['arnger'],
      classifiers=CLASSIFIERS,
      install_requires=REQUIREMENTS,
      keywords='lawrence sample'
      )
